#ifndef _SU3_H
#define _SU3_H

#include "complex.h"

/******************************  su3.h **********************************
*									*
*  Defines and subroutine declarations for SU3 simulation		*
*  MIMD version 6 							*
*									*
*/
/* SU(3) */
typedef struct { complex e[3][3]; } su3_matrix;
typedef struct { complex c[3]; } su3_vector;
typedef struct { su3_vector h[2]; } half_wilson_vector;

/*
* ROUTINES FOR SU(3) MATRIX OPERATIONS
*
* void mult_su3_nn(  su3_matrix *a, su3_matrix *b, su3_matrix *c  )
*	matrix multiply, no adjoints
*	files "m_mat_nn.c", "m_mat_nn.m4"
* void mult_su3_mat_vec( su3_matrix *a, su3_vector *b, su3_vector *c )
*	 C  <-  A*B
*	file "m_matvec.c", "m_matvec.m4"
* void mult_su3_mat_hwvec( su3_matrix *mat, half_wilson_vector *src,
*	half_wilson_vector *dest );
*	file m_mat_hwvec.c
*	   dest <- mat*src
*/

void mult_su3_nn ( su3_matrix *a, su3_matrix *b, su3_matrix *c );
void mult_su3_mat_vec( su3_matrix *a, su3_vector *b, su3_vector *c );
void mult_su3_mat_hwvec( su3_matrix *mat, half_wilson_vector *src,
			 half_wilson_vector *dest );
void mult_adj_su3_mat_vec_4dir( su3_matrix *mat, su3_vector *src, su3_vector *dest );
void mult_su3_mat_vec_sum_4dir(  su3_matrix *a, su3_vector *b0,
				 su3_vector *b1, su3_vector *b2, su3_vector *b3, su3_vector *c  );

#endif /* _SU3_H */
